@@ -10,6 +10,7 @@ import argparse
 import subprocess
 import sys
 
+from docker import errors
 ##importing required files
 
 #import linguDetect/lingu_detect as ling
@@ -95,6 +96,8 @@ def runImage(data=None,type=None):
 
     userid= f"{uid}:{gid}"
 
+    logging.info('Running all the scans/docker with the user %s',userid)
+
     if type == 'SAST':
         target_file = Config.sast_target
         Utils.checkImageAlreadyExsist(docker_image)
@@ -108,15 +111,17 @@ def runImage(data=None,type=None):
         
        
         detach = True if data['detach'] == 1 else False
-        
+        container_output = None
         try:
             Config.build_dir = Config.sast_build_dir
             container_output = docker.containers.run(docker_image, command_line, volumes={Config.sast_build_dir: {
                             'bind': data['bind']}}, user=userid,detach=detach)
             logging.info('[SUCCESS]: %s Scan Completed',tool_name)
-        except:
-            #print(container_output)
+        except errors.ContainerError as exc: 
+            msg='\n The following error has been recorded while scanning SAST'
+            Utils.logError(msg,str(exc))
             logging.error('[WARNING]: Some Error recorded while scanning %s',tool_name)   ## need to rewrite the logic here --MM
+            
    
 
         try:
@@ -142,8 +147,10 @@ def runImage(data=None,type=None):
                     with open(Config.sast_build_dir+output_file, 'w', encoding='utf-8') as f:
                         json.dump(json.loads(container_output), f, ensure_ascii=False, indent=4)
                         uploadReport(output_file,tool_name,tool_id,scan_details_id)
-        except:
+        except EnvironmentError as e:
             logging.WARNING('Error while uploading the report of %s',tool_name)    
+            msg='Error while uploading the report'
+            Utils.logError(msg,e)
             
 
 
@@ -170,9 +177,11 @@ def runImage(data=None,type=None):
             #print(output_file,toolname,tool_id,scan_details_id)
             logging.info('[SUCCESS]: %s Scan Completed',tool_name)
             
-        except:
-            #print(container)
-            logging.error('Error recorded while Scanning %s',tool_name)
+        except errors.ContainerError as exc: 
+            logging.error('[ERROR]: Error recorded while Scanning %s',tool_name)
+            msg='\n The following error has been recorded while scanning DAST'
+            Utils.logError(msg,str(exc))
+            
 
         try:
             if will_generate_output == 1:
@@ -192,9 +201,10 @@ def runImage(data=None,type=None):
             container_output = docker.containers.run(docker_image, command_line, volumes={Config.sca_build_dir: {
                      'bind': data['bind']}}, user=uid)
             logging.info('[SUCCESS]: %s Scan Completed',tool_name)
-        except:
-
-            logging.error('Some Error recorded while scanning %s',tool_name)  
+        except errors.ContainerError as exc: 
+           logging.error('Some Error recorded while scanning %s',tool_name)  
+           msg='\n The following error has been recorded while scanning sca'
+           Utils.logError(msg,str(exc))
          
         try:
             if will_generate_output == 1:
@@ -203,8 +213,10 @@ def runImage(data=None,type=None):
             else:
                 logging.error('Cant upload files to the server',tool_name)
 
-        except:    
+        except EnvironmentError as e:    
             logging.error('Error recorded while uploading the report %s',tool_name)             ## need to change logic here -- MM   
+            msg = 'Error recorded while uploading the report'
+            Utils.logError(msg,e)          ## need to change logic here -- MM   
 
 
 
@@ -224,7 +236,8 @@ def uploadReport(filename,toolname,tool_id,scan_details_id): #,scan_token,tool_i
                 data = json.load(f)
         except EnvironmentError as e:
             logging.error('Error while fetching the output file from the directory')
-            logging.debug(e)
+            msg = 'Error while fetching the output file from the directory'
+            Utils.logError(msg,str(e))
             return 0
  
         tool_output = json.dumps(data, ensure_ascii=False, indent=4)
@@ -282,8 +295,10 @@ def initSecertScan(path,data):
 
        
         logging.info('[SUCCESS]: Secert Scanning Completed ')            
-    except ContainerError as exc:
+    except errors.ContainerError as exc:
         logging.error('Error Occured while running Trufflehog on the repository') 
+        msg='\n The following error has been recorded while scanning Trufflehog'
+        Utils.logError(msg,str(exc)) 
 
 
     try:
